pynrc.DetectorOps
=================

.. currentmodule:: pynrc

.. autoclass:: DetectorOps
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DetectorOps.__init__
      ~DetectorOps.int_times_table
      ~DetectorOps.make_header
      ~DetectorOps.pix_timing_map
      ~DetectorOps.pixel_noise
      ~DetectorOps.times_to_dict
      ~DetectorOps.to_dict
      ~DetectorOps.xtalk
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DetectorOps.channel
      ~DetectorOps.chsize
      ~DetectorOps.detid
      ~DetectorOps.detid_list
      ~DetectorOps.detname
      ~DetectorOps.fastaxis
      ~DetectorOps.mask_act
      ~DetectorOps.mask_channels
      ~DetectorOps.mask_ref
      ~DetectorOps.module
      ~DetectorOps.nff
      ~DetectorOps.nout
      ~DetectorOps.ref_info
      ~DetectorOps.scaid
      ~DetectorOps.scaid_list
      ~DetectorOps.slowaxis
      ~DetectorOps.time_exp
      ~DetectorOps.time_frame
      ~DetectorOps.time_group
      ~DetectorOps.time_int
      ~DetectorOps.time_int_eff
      ~DetectorOps.time_ramp
      ~DetectorOps.time_ramp_eff
      ~DetectorOps.time_row_reset
      ~DetectorOps.time_total
      ~DetectorOps.time_total_int1
      ~DetectorOps.time_total_int2
      ~DetectorOps.times_group_avg
      ~DetectorOps.wind_mode
      ~DetectorOps.x0
      ~DetectorOps.xpix
      ~DetectorOps.y0
      ~DetectorOps.ypix
   
   